==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcOfIpSrcCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcOfIpSrcCaseBuilder} instances.
 *
 * @see SrcOfIpSrcCaseBuilder
 *
 */
public class SrcOfIpSrcCaseBuilder implements Builder<SrcOfIpSrcCase> {

    private Boolean _ofIpSrc;


    Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> augmentation = Collections.emptyMap();

    public SrcOfIpSrcCaseBuilder() {
    }
    public SrcOfIpSrcCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping arg) {
        this._ofIpSrc = arg.isOfIpSrc();
    }

    public SrcOfIpSrcCaseBuilder(SrcOfIpSrcCase base) {
        this._ofIpSrc = base.isOfIpSrc();
        if (base instanceof SrcOfIpSrcCaseImpl) {
            SrcOfIpSrcCaseImpl impl = (SrcOfIpSrcCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> aug =((AugmentationHolder<SrcOfIpSrcCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping) {
            this._ofIpSrc = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping)arg).isOfIpSrc();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping]");
    }

    public Boolean isOfIpSrc() {
        return _ofIpSrc;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<SrcOfIpSrcCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcOfIpSrcCaseBuilder setOfIpSrc(final Boolean value) {
        this._ofIpSrc = value;
        return this;
    }
    
    public SrcOfIpSrcCaseBuilder addAugmentation(Class<? extends Augmentation<SrcOfIpSrcCase>> augmentationType, Augmentation<SrcOfIpSrcCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcOfIpSrcCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcOfIpSrcCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcOfIpSrcCase build() {
        return new SrcOfIpSrcCaseImpl(this);
    }

    private static final class SrcOfIpSrcCaseImpl implements SrcOfIpSrcCase {
    
        private final Boolean _ofIpSrc;
    
        private Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> augmentation = Collections.emptyMap();
    
        SrcOfIpSrcCaseImpl(SrcOfIpSrcCaseBuilder base) {
            this._ofIpSrc = base.isOfIpSrc();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcOfIpSrcCase> getImplementedInterface() {
            return SrcOfIpSrcCase.class;
        }
    
        @Override
        public Boolean isOfIpSrc() {
            return _ofIpSrc;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<SrcOfIpSrcCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofIpSrc);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcOfIpSrcCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcOfIpSrcCase other = (SrcOfIpSrcCase)obj;
            if (!Objects.equals(_ofIpSrc, other.isOfIpSrc())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcOfIpSrcCaseImpl otherImpl = (SrcOfIpSrcCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcOfIpSrcCase");
            CodeHelpers.appendValue(helper, "_ofIpSrc", _ofIpSrc);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcOfIpSrcCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcOfIpSrcCaseBuilder} instances.
 *
 * @see SrcOfIpSrcCaseBuilder
 *
 */
public class SrcOfIpSrcCaseBuilder implements Builder<SrcOfIpSrcCase> {

    private Boolean _ofIpSrc;


    Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> augmentation = Collections.emptyMap();

    public SrcOfIpSrcCaseBuilder() {
    }
    public SrcOfIpSrcCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping arg) {
        this._ofIpSrc = arg.isOfIpSrc();
    }

    public SrcOfIpSrcCaseBuilder(SrcOfIpSrcCase base) {
        this._ofIpSrc = base.isOfIpSrc();
        if (base instanceof SrcOfIpSrcCaseImpl) {
            SrcOfIpSrcCaseImpl impl = (SrcOfIpSrcCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> aug =((AugmentationHolder<SrcOfIpSrcCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping) {
            this._ofIpSrc = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping)arg).isOfIpSrc();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpSrcGrouping]");
    }

    public Boolean isOfIpSrc() {
        return _ofIpSrc;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcOfIpSrcCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcOfIpSrcCaseBuilder setOfIpSrc(final Boolean value) {
        this._ofIpSrc = value;
        return this;
    }
    
    public SrcOfIpSrcCaseBuilder addAugmentation(Class<? extends Augmentation<SrcOfIpSrcCase>> augmentationType, Augmentation<SrcOfIpSrcCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcOfIpSrcCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcOfIpSrcCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcOfIpSrcCase build() {
        return new SrcOfIpSrcCaseImpl(this);
    }

    private static final class SrcOfIpSrcCaseImpl implements SrcOfIpSrcCase {
    
        private final Boolean _ofIpSrc;
    
        private Map<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> augmentation = Collections.emptyMap();
    
        SrcOfIpSrcCaseImpl(SrcOfIpSrcCaseBuilder base) {
            this._ofIpSrc = base.isOfIpSrc();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcOfIpSrcCase> getImplementedInterface() {
            return SrcOfIpSrcCase.class;
        }
    
        @Override
        public Boolean isOfIpSrc() {
            return _ofIpSrc;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<SrcOfIpSrcCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofIpSrc);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcOfIpSrcCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcOfIpSrcCase other = (SrcOfIpSrcCase)obj;
            if (!Objects.equals(_ofIpSrc, other.isOfIpSrc())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcOfIpSrcCaseImpl otherImpl = (SrcOfIpSrcCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcOfIpSrcCase>>, Augmentation<SrcOfIpSrcCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcOfIpSrcCase");
            CodeHelpers.appendValue(helper, "_ofIpSrc", _ofIpSrc);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
